// human_player.as

if (Object.Swim == null) {
	Object.Swim = {};
}

if (Object.Swim.HumanPlayer == null) {
	Object.Swim.HumanPlayer = {};
}

var HumanPlayer = Object.Swim.HumanPlayer;

Object.Swim.HumanPlayer.initHumanPlayer = function (id, maxCards, chances, showMe, playerName) {
	findProto(Object.Swim.HumanPlayer).implement (Object.Swim.Player);
	this.initPlayer (id, maxCards, chances, showMe, playerName);
	
	this.playerProto = findProto(Object.Swim.Player);
	
	this.delayTime = 1500;
	
	// buttons
	
	this.buttons = {
		takeOne 	: takeOneBtn,
		takeAll 	: takeAllBtn,
		pass 			: passBtn,
		knock 		: knockBtn
	};
	
	for (var button in buttons) {
		buttons[button].implement(Object.Button);
		buttons[button].initButton();
	}
	
	for (var i = 0; i<this.maxCards; i++) {
		this.attachMovie("slotBtn", "slot" + i, i);
		this["slot" + i].implement(Object.Button);
		this["slot" + i].initButton("hide");
		
		this.attachMovie("slotBtn", "stack" + i, Number(i + this.maxCards) );
		this["stack" + i].implement(Object.Button);
		this["stack" + i].initButton("hide");
	}
	
	// opening screen
	
	this.opening.implement (Object.Swim.HumanPlayerOpening);
	this.opening.initHumanPlayerOpening(true, this.playerName);
	
	this.gotoAndStop("off");
} // initHumanPlayer

HumanPlayer.showLastMoves = function () {
	var movecount = this.lastMoves.length;
	var move;
	var track;
	
	this.lastMovesDisp = "";

	for (var i=0; i<movecount; i++) {
		move = this.lastMoves[i];
		// trace ("move: " + move.type);
		if (move.type == "move") {
			track = move.player.getPlayerName() + " ";

			if (move.move == "takeOne") {
				track += "takes " + move.card.getDesc();
			} 
			else  if (move.move == "takeAll") {
				track += "takes " + _parent.getCardsDesc (move.cards);
			}
			else if (move.move == "pass") {
				track += "passes";
			} 
			else if (move.move == "knock") {
				track += "knocks";
			}
			track += ".";
		}
		else if (move.type == "newCards") {	
			track = "New Cards: " +_parent.getCardsDesc(move.cards);
		}
		else if (move.type == "message") {
			track = move.message;
		}
			
		this.lastMovesDisp += track + newline;
	}
} // showLastMoves

HumanPlayer.showScore = function () {
	this.scoreDisp = this.getScore ();
} // showScore

HumanPlayer.looseChance = function () {
	this._looseChance = this.playerProto.looseChance;
	var chances =	this._looseChance();
	delete this._looseChance;
	
	this.chanceMeter.gotoAndStop (chances+2);
	return chances;
} // loseChance

HumanPlayer.resetChances = function () {
	this._resetChances = this.playerProto.resetChances;
	var chances = this._resetChances();
	delete this._resetChances;

	if (this.chanceMeter._currentFrame < chances + 2) {
		this.chanceMeter.play();
	}
	return chances;
} // resetChances

HumanPlayer.reset = function () {
	this.deactivateButtons();
	this.scoreDisp = "";
	
	this._reset = this.playerProto.reset;
	this._reset();
	delete this._reset;
} // reset

HumanPlayer.yourTurn = function (lastMoves) {
	this._yourTurn = this.playerProto.yourTurn;
	this._yourTurn ( lastMoves );
	delete this._yourTurn;
	
	this.opening.show();
	
	this.show();
	this.hideHand();
}// yourTurn

HumanPlayer.startTurn = function () {
	this.opening.hide();

	this.activateButtons();
	this.showLastMoves();
	this.showScore();
	
	this.currentSlot = null;
	this.currentStack = null;

	_parent.stack.show();
	_parent.screens.show();
	this.showHand();
} // startTurn

HumanPlayer.endOfTurn = function () {
	this.analyzeHand();
	this.showScore();
	
	_parent.screens.deactivate();

	this.startWait = getTimer();
	
	this.gotoAndStop("endDelay");
	
} // endOfTurn

HumanPlayer.checkDelay = function () {
	if (getTimer() - this.startWait >= this.delayTime) {
		this.gotoAndStop("off");
		this.HumanEndOfTurn();
	}
}


HumanPlayer.HumanEndOfTurn = function () {
	this.deactivateButtons();
	_parent.screens.activate();
	
	_parent.stack.hide();
	this.hide();
	
	this._endOfTurn = this.playerProto.endOfTurn;
	this._endOfTurn();
	delete this._endOfTurn;
} // HumanEndOfTurn



//
// button actions
//

HumanPlayer.activateButtons = function () {
	buttons.takeOne.set ("off");
	buttons.takeAll.set ("active");
	buttons.pass.set ("active");
	if (!this.firstTurn && _parent.getKnockPlayer() == null) {
		buttons.knock.set ("active");
	} 
	else {
		buttons.knock.set("off");
	}
	var card; 
	var btnPos = { x: 0, y: 0};
	
	for (var i = 0; i<this.maxCards; i++) {
	
		this["slot" + i].placeClip (btnPos, this.cards[i]);	
		this["slot" + i].set("active");
		
		this["stack" + i].placeClip (btnPos, this.stackCards[i]);	
		this["stack" + i].set("active");
	}
}

HumanPlayer.deactivateButtons = function () {
	for (var btn in this.buttons) {
		this.buttons[btn].set("hide");
	}
	
	for (var i = 0; i<this.maxCards; i++) {
		this["slot"  + i].hide();
		this["stack" + i].hide();
	}
}

HumanPlayer.highlightButton = function (button) {
	for (var btn in this.buttons) {
		this.buttons[btn] != button ?
			this.buttons[btn].set("off") :
			button.set ("selected"); 
	}
	
		for (var i = 0; i<this.maxCards; i++) {
		if (this["slot"  + i].get() != "selected") {
			this["slot"  + i].hide();
		}
		if (this["stack" + i].get() != "selected") {
			this["stack" + i].hide();
		}
	}
	
}

HumanPlayer.selectSlot = function (buttonName) {
	if (this.currentSlot != null && this.currentSlot != buttonName) {
		this[this.currentSlot].set("active");
	}
	this[buttonName].set("selected");
	this.currentSlot = buttonName;
	
	if (this.currentStack != null) {
		buttons.takeOne.set("active");
	}
}

HumanPlayer.selectStack = function (buttonName) {
	if (this.currentStack != null && this.currentStack != buttonName) {
		this[this.currentStack].set("active");
	}
	this[buttonName].set("selected");
	this.currentStack = buttonName;

	if (this.currentSlot != null) {
		buttons.takeOne.set("active");
	}
}

HumanPlayer.buttonRelease = function (button) {
	if (substring (button._name,1,4) == "slot") {
		this.selectSlot (button._name);
	}
	else if (substring (button._name,1,5) == "stack") {
		this.selectStack (button._name);
	}
	else {

		if (button == this.takeOneBtn) {
			this.takeOne();
		} 
		else if (button == this.takeAllBtn) {
			this.takeAll();
		} 
		else if (button == this.passBtn) {
			this.pass();
		} 
		else if (button == this.knockBtn ) {
			this.knock();
		} 
	
		this.highlightButton (button);
	}
 
}

delete HumanPlayer;


