import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintWriter;

/**
 * Encapsulates the functionality of a response. It is essentially a
 * DataOutputStream.
 *
 * @author Christian Cantrell
 * @version $Id: PocketResponse.java,v 1.8 2001/09/09 05:05:39 cantrell Exp $
 */
public class PocketResponse
    extends PrintWriter 
{
    /**
     * Create a new PocketResponse and set autoflush to true. The PocketResponse
     * will get automatically flushed after println() is called.
     */
    public PocketResponse(OutputStream out)
    {
        super(out,true);
    }

    /**
     * Sends a 400 response code followed by a newline followed by a message
     * about what went wrong, then flushes and closes the OutputStream. A 400
     * indicates that the server did not understand the request.
     *
     * @param msg Whatever information is know about what went wrong.
     * @param problem The exception if there was one, otherwise null.
     */
    public void badRequest(String msg,
                           Throwable problem)
    {
        processReturnCode("r400",msg,problem);
    }

    /**
     * Sends a 404 response code followed by a newline followed by a message
     * about what went wrong, then flushes and closes the OutputStream. A 404
     * indicates that the request resources was not found on the server.
     *
     * @param msg Whatever information is know about what went wrong.
     * @param problem The exception if there was one, otherwise null.
     */
    public void notFound(String msg,
                         Throwable problem)
    {
        processReturnCode("r404",msg,problem);
    }

    /**
     * Sends a 500 response code followed by a newline followed by a message
     * about what went wrong, then flushes and closes the OutputStream. A 500
     * indicates an error on the server.
     *
     * @param msg Whatever information is know about what went wrong.
     * @param problem The exception if there was one, otherwise null.
     */
    public void internalServerError(String msg,
                                    Throwable problem)
    {
        processReturnCode("r500",msg,problem);
    }

    /**
     * Sends a 200 indicating the request was successfully serviced. 
     */
    public void ok()
    {
        processReturnCode("r200",null,null);
    }

    private void processReturnCode(String code,
                                   String msg,
                                   Throwable problem)
    {
        println(code);
        if (msg != null)
        {
            println(msg);
        }
        if (problem != null)
        {
            println(problem.toString());
            problem.printStackTrace((PrintWriter)this);
        }
        flush();
        close();
        return;
    }
}
