import java.io.File;
import java.io.OutputStream;
import java.util.Properties;

/**
 * A PocketService which simply removes a file. The following parameters must be
 * present in the request:
 * <ul>
 *   <li>
 *     fileName - The name of the file to remove.
 *   </li>
 * </ul>
 *
 * @author Christian Cantrell
 * @version $Id: RemoveFile.java,v 1.7 2001/09/09 05:05:39 cantrell Exp $
 */
public class RemoveFile
    extends PocketService
{
    /**
     * The directory where files will be removed. This must be specified by the
     * server rather than letting the client specify the entire path for
     * security reasons. We have to make sure critical files are not
     * removed.
     */
    private String dir;

    protected void initSupport()
        throws PocketInitException
    {
        dir = props.getProperty("RemoveFile.removeBaseDir");
        if (dir == null)
        {
            throw new PocketInitException("The PocketService RemoveFile " +
                                          "cannot be initialized w/o the " +
                                          "property RemoveFile.removeBaseDir" + 
                                          " defined."); 
        }

        if (!dir.endsWith(File.separator))
        {
            dir += File.separator;
        }
    }

    protected void service(PocketRequest request,
                           PocketResponse response)
        throws PocketServiceException
    {
        String fileName = (String) request.get("fileName");
        if (fileName == null)
        {
            throw new PocketServiceException("RemoveFile does not have the " +
                                             "information it needs to remove " +
                                             "a file. You must pass in " +
                                             "fileName."); 
        }

        if (fileName.startsWith(File.separator))
        {
            fileName = fileName.substring(1,fileName.length());
        }

        fileName = dir + fileName;

        try
        {
            File file = new File(fileName);
            if (!file.delete())
            {
                throw new PocketServiceException("Problem removing file [" +
                                                 fileName + "].");
            }
            response.ok();
            return; 
        }
        catch (SecurityException exception)
        {
            throw new PocketServiceException("Problem removing file [" +
                                             fileName + "] for security " +
                                             "reasons: " + exception);
        }
    }
}
