import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.OutputStream;
import java.util.Properties;

/**
 * A PocketService which simply writes a file. The following parameters must be
 * present in the request:
 * <ul>
 *   <li>
 *     fileName - The name of the file to save. If you prepend directory
 *     information, it will be relative to the init property
 *     SaveFile.saveBaseDir.
 *   </li>
 *   <li>fileContent - The content of the file to save.</li>
 *   <li>
 *     append (optional) - If true, and the file already exists, append to it
 *     rather than overwrite it. Default is false.
 *   </li>
 * </ul>
 *
 * @author Christian Cantrell
 * @version $Id: SaveFile.java,v 1.9 2001/09/09 05:05:39 cantrell Exp $
 */
public class SaveFile
    extends PocketService
{
    /**
     * The directory where files will be saved. This must be specified by the
     * server rather than letting the client specify the entire path for
     * security reasons. We have to make sure critical files are not
     * overwritten.
     */
    private String dir;

    protected void initSupport()
        throws PocketInitException
    {
        dir = props.getProperty("SaveFile.saveBaseDir");
        if (dir == null)
        {
            throw new PocketInitException("The PocketService SaveFile cannot " +
                                          "be initialized w/o the property " +
                                          "SaveFile.saveBaseDir defined."); 
        }

        if (!dir.endsWith(File.separator))
        {
            dir += File.separator;
        }
    }

    protected void service(PocketRequest request,
                           PocketResponse response)
        throws PocketServiceException
    {
        String fileName = request.getParameter("fileName");
        String fileContent = request.getParameter("fileContent");
        if (fileName == null ||
            fileContent == null)
        {
            throw new PocketServiceException("SaveFile does not have all the " +
                                             "information it needs to save " +
                                             "a file. You must pass in " +
                                             "fileName and fileContent."); 
        }

        if (fileName.startsWith(File.separator))
        {
            fileName = fileName.substring(1,fileName.length());
        }

        fileName = dir + fileName;

        String appendStr = (String) request.get("append");
        boolean append = (appendStr == null) ? 
                         false :
                         Boolean.valueOf(appendStr).booleanValue(); 

        try
        {
            FileWriter writer = new FileWriter(fileName, append);
            writer.write(fileContent);
            writer.flush();
            writer.close();
            response.ok();
            return; 
        }
        catch (IOException exception)
        {
            throw new PocketServiceException("Problem creating and writing " +
                                             "to file [" + fileName + "]: " +
                                             exception);
        }
    }
}
